@@ -31,17 +31,14 @@ sub opt_spec {
 }
 
 sub usage_desc {
-    my $self = shift;
-    my $desc = $self->SUPER::usage_desc;    # "%c COMMAND %o"
-    $desc .= " <infile> [more infiles]";
-    return $desc;
+    return "fasops axt2fas [options] <infile> [more infiles]";
 }
 
 sub description {
     my $desc;
     $desc
         .= "Convert UCSC axt pairwise alignment file to blocked fasta file.\n";
-    $desc .= "\tinfiles are paths to axt files, .axt.gz is supported\n";
+    $desc .= "\tInfiles are paths to axt files, .axt.gz is supported\n";
     return $desc;
 }
 
@@ -49,7 +46,10 @@ sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
     if ( !@{$args} ) {
-        $self->usage_error("This command need one or more input files.");
+        my $message = "This command need one or more input files.\n\tIt found";
+        $message .= sprintf " [%s]", $_ for @{$args};
+        $message .= ".\n";
+        $self->usage_error($message);
     }
     for ( @{$args} ) {
         if ( !Path::Tiny::path($_)->is_file ) {
