@@ -15,10 +15,7 @@ sub opt_spec {
 }
 
 sub usage_desc {
-    my $self = shift;
-    my $desc = $self->SUPER::usage_desc;    # "%c COMMAND %o"
-    $desc .= " <infile> [more infiles]";
-    return $desc;
+    return "fasops links [options] <infile> [more infiles]";
 }
 
 sub description {
@@ -33,7 +30,10 @@ sub validate_args {
     my ( $self, $opt, $args ) = @_;
 
     if ( !@{$args} ) {
-        $self->usage_error("This command need one or more input files.");
+        my $message = "This command need one or more input files.\n\tIt found";
+        $message .= sprintf " [%s]", $_ for @{$args};
+        $message .= ".\n";
+        $self->usage_error($message);
     }
     for ( @{$args} ) {
         if ( !Path::Tiny::path($_)->is_file ) {
